# PerceptualTests
This repository contains different tests to assess the perceptual behaviour of visual system models.

# Installation
Right now, the package is not available on conda but can cloned and installed with ease or be installed from pip:

## pip

This should be the last stable version. Might be missing some features that we are developing in the repo, but should work nonetheless.

```
pip install perceptualtests
```

## GitHub

This will install the **development** version, which probably has more features than the one on `pip` but is more prone to bugs and unexepected behaviours.

```
git clone https://github.com/Jorgvt/PerceptualTests.git
cd perceptualtests
pip install -e .
```
